@@ -21,8 +21,6 @@
 import inspect
 import sys
 
-import six
-
 from keystoneauth1.exceptions import base
 
 
@@ -380,7 +378,7 @@ class HttpVersionNotSupported(HttpServerError):
 # _code_map contains all the classes that have http_status attribute.
 _code_map = dict(
     (getattr(obj, 'http_status', None), obj)
-    for name, obj in six.iteritems(vars(sys.modules[__name__]))
+    for name, obj in vars(sys.modules[__name__]).items()
     if inspect.isclass(obj) and getattr(obj, 'http_status', False)
 )
 
